from tkinter import ttk, messagebox
import hashlib

class CreateAccountPage:
    def __init__(self, master, main_window, db_manager):
        self.master = master
        self.main_window = main_window
        self.db_manager = db_manager
        self.master.title("Create Account")
        self.master.geometry("500x600")
        self.master.configure(bg='#2B2B2B')

        font_style = ("Calibri", 12)

        username_label = ttk.Label(self.master, text="Enter your username:", font=font_style, foreground="white", background='#2B2B2B')
        username_label.place(relx=0.5, rely=0.3, anchor="center")

        self.username_entry = ttk.Entry(self.master, font=font_style, style="TEntry")
        self.username_entry.place(relx=0.5, rely=0.35, anchor="center")

        password_label = ttk.Label(self.master, text="Enter your password:", font=font_style, foreground="white", background='#2B2B2B')
        password_label.place(relx=0.5, rely=0.45, anchor="center")

        self.password_entry = ttk.Entry(self.master, show="*", font=font_style, background='white')
        self.password_entry.place(relx=0.5, rely=0.5, anchor="center")

        repeat_password_label = ttk.Label(self.master, text="Repeat your password:", font=font_style, foreground="white", background='#2B2B2B')
        repeat_password_label.place(relx=0.5, rely=0.55, anchor="center")

        self.repeat_password_entry = ttk.Entry(self.master, show="*", font=font_style)
        self.repeat_password_entry.place(relx=0.5, rely=0.6, anchor="center")

        create_button = ttk.Button(self.master, text="Create", command=self.create_account, style='TButton')
        create_button.place(relx=0.5, rely=0.68, anchor="center")

    def create_account(self):
        entered_username = self.username_entry.get()
        entered_password = self.password_entry.get()
        repeat_password = self.repeat_password_entry.get()

        if entered_password != repeat_password:
            messagebox.showerror("Error", "Passwords do not match. Please try again.")
            return

        hashed_password = hashlib.sha256(entered_password.encode()).hexdigest()

        self.db_manager.insert_user(entered_username, hashed_password)
        messagebox.showinfo("Account Created", "Your account has been created successfully!")

        self.master.destroy()
        self.open_login_page()

    def open_login_page(self):
        self.main_window.deiconify()