import tkinter as tk
from tkinter import ttk, messagebox
import hashlib
from PIL import Image, ImageTk
import createaccountpage as capage
import passwordgeneratorapp as pas

class LoginPage:
    def __init__(self, master, db_manager):
        self.master = master
        self.db_manager = db_manager
        self.master.title("VaultyPiste - Keep Your Passwords Safe and Sound")
        self.master.geometry("500x600")
        self.master.configure(bg='#2B2B2B')
        self.login_attempts = 3

        img_path = "./2.png"
        pil_img = Image.open(img_path)
        pil_img = pil_img.resize((200, 200))
        self.img = ImageTk.PhotoImage(pil_img)
        img_label = tk.Label(self.master, image=self.img, background='#2B2B2B')
        img_label.image = self.img
        img_label.place(relx=0.01, rely=0.01)

        self.create_widgets()

    # Create the *Info* button
        info_button = ttk.Button(self.master, text="Info", command=self.show_info)
        info_button.place(relx=0.50, rely=0.90, anchor="center")

    def show_info(self):
        info_text = """Using a password manager is a secure way to store and manage your passwords. 
        
    Here are some tips to ensure maximum security:
    
    1. Make sure your master password is unique, long, and complex.

    2. Enable two-factor authentication (2FA) if available: Adding an extra layer of security is always beneficial.

    3. Keep your password manager software up-to-date to benefit from the latest security patches.

    4. Be cautious about storing highly sensitive information other than passwords in your password manager.
    """
        messagebox.showinfo("Password Manager Security Information", info_text)

    def create_widgets(self):
        font_style = ("Calibri", 12)

        username_label = ttk.Label(self.master, text="Username:", font=font_style, foreground="white", background='#2B2B2B')
        username_label.place(relx=0.5, rely=0.3, anchor="center")

        self.username_entry = ttk.Entry(self.master, font=font_style, style="TEntry")
        self.username_entry.place(relx=0.5, rely=0.35, anchor="center")

        password_label = ttk.Label(self.master, text="Password:", font=font_style, foreground="white", background='#2B2B2B')
        password_label.place(relx=0.5, rely=0.45, anchor="center")

        self.password_entry = ttk.Entry(self.master, show="*", font=font_style, background='white')
        self.password_entry.place(relx=0.5, rely=0.5, anchor="center")

        login_button = ttk.Button(self.master, text="Login", command=self.validate_login, style='TButton')
        login_button.place(relx=0.5, rely=0.6, anchor="center")

        create_account_button = ttk.Button(self.master, text="Create Account", command=self.create_account, style='TButton')
        create_account_button.place(relx=0.5, rely=0.68, anchor="center")

        font_style_small = ("Calibri", 10)
        self.attempts_label = ttk.Label(self.master, text="You have 3 attempts", font=font_style_small, foreground="white", background='#2B2B2B')
        self.attempts_label.place(relx=0.5, rely=0.95, anchor="center")

    def validate_login(self):
        entered_username = self.username_entry.get()
        entered_password = self.password_entry.get()

        stored_password = self.db_manager.get_user(entered_username)
        if stored_password is not None:
            hashed_password = hashlib.sha256(entered_password.encode()).hexdigest()
            if hashed_password == stored_password:
                messagebox.showinfo("Login Successful", "Welcome, " + entered_username + "!")
                self.open_password_generator()
                return
            
        # Handle invalid login attempts
        self.login_attempts -= 1
        if self.login_attempts > 0:
            self.attempts_label.config(
                text=f"Invalid username or password. You have {self.login_attempts} attempts remaining.")
        else:
            messagebox.showerror("Login Failed", "Too many unsuccessful login attempts. Closing application.")
            self.master.destroy()

    def create_account(self):
        self.master.withdraw()
        root = tk.Toplevel()
        app = capage.CreateAccountPage(root, self.master, self.db_manager)
        root.mainloop()

    def open_password_generator(self):
        self.master.destroy()
        root = tk.Tk()
        app = pas.PasswordGeneratorApp(root)
        root.mainloop()
        