import tkinter as tk
from tkinter import ttk, messagebox
import random
from PIL import Image, ImageTk
from tkinter import filedialog
import sandy 


class PasswordGeneratorApp:
    def __init__(self, master):
        self.master = master
        self.master.title("-VP.")
        self.master.geometry("500x750")
        self.master.configure(bg='#2B2B2B')

        self.create_widgets()

    # Adding the close confirmation
        self.master.protocol("WM_DELETE_WINDOW", self.on_closing)

    def on_closing(self):
        if messagebox.askokcancel("Quit", "Do you want to logout?"):
            # Perform logout actions here
            print("Logging out...")
            self.master.destroy()

    def create_widgets(self):
        font_style = ("Calibri", 11)

        white_color = "white"
        bg_color = '#2B2B2B'

        img_path = "2.png"
        pil_img = Image.open(img_path)
        pil_img = pil_img.resize((120, 120))

        img = ImageTk.PhotoImage(pil_img)
        img_label = tk.Label(self.master, image=img, background=bg_color)
        img_label.image = img
        img_label.pack(side="top", anchor="nw", padx=10, pady=10)

        ttk.Label(self.master, text="Password length:", font=font_style, foreground=white_color,
                  background=bg_color).pack(side="top", anchor="w", padx=40)
        self.length_entry = ttk.Entry(self.master)
        self.length_entry.pack(side="top", anchor="w", padx=40)

        ttk.Label(self.master, text="Quantity:", font=font_style, foreground=white_color,
                  background=bg_color).pack(side="top", anchor="w", padx=40)
        self.amount_entry = ttk.Entry(self.master)

        self.amount_entry.pack(side="top", anchor="w", padx=40)

        checkbutton_style = ttk.Style()
        checkbutton_style.configure('TCheckbutton', font=("Calibri", 16), foreground=white_color, background=bg_color)

        self.num_var = tk.BooleanVar()
        num_checkbutton = ttk.Checkbutton(self.master, text="Numbers", variable=self.num_var)
        num_checkbutton.pack(anchor="w", padx=40)

        self.lower_var = tk.BooleanVar()
        lower_checkbutton = ttk.Checkbutton(self.master, text="Lowercase", variable=self.lower_var)
        lower_checkbutton.pack(anchor="w", padx=40)

        self.upper_var = tk.BooleanVar()
        upper_checkbutton = ttk.Checkbutton(self.master, text="Uppercase", variable=self.upper_var)
        upper_checkbutton.pack(anchor="w", padx=40)

        self.symbols_var = tk.BooleanVar()
        symbols_checkbutton = ttk.Checkbutton(self.master, text="Symbols", variable=self.symbols_var)
        symbols_checkbutton.pack(anchor="w", padx=40)

        self.extra_var = tk.BooleanVar()
        extra_checkbutton = ttk.Checkbutton(self.master, text="Extra", variable=self.extra_var)
        extra_checkbutton.pack(anchor="w", padx=40)

        ttk.Button(self.master, text="Generate Password", command=self.generate_passwords).pack(pady=20)

        self.password_display = tk.Text(self.master, height=10, width=50, wrap="word")
        self.password_display.pack(side="top", padx=40, pady=20)

        # txt button
        ttk.Button(self.master, text="Open Text File", command=self.open_file_dialog).pack(pady=20) 

        # To save the file
        self.master.bind('s', self.save_file)  

    # Function for txt
    def open_file_dialog(self): 
        filename = filedialog.askopenfilename(title="Select a text file", filetypes=(("Text files", "*.txt"), ("All files", "*.*")))
        sandy.generate_key()
        key = sandy.load_key()
        sandy.decrypt_file(filename, key)
        if filename:
            with open(filename, 'r') as file:
                content = file.read()
                self.display_file_content(content)
                sandy.encrypt_file(filename, key)

    def display_file_content(self, content):
        self.password_display.delete(1.0, tk.END)
        self.password_display.insert(tk.END, content)
        
    # Function to save the file
    def save_file(self, event=None): 
        filename = filedialog.asksaveasfilename(defaultextension=".txt", filetypes=(("Text files", "*.txt"), ("All files", "*.*")))
        if filename:
            with open(filename, 'w') as file:
                file.write(self.password_display.get(1.0, tk.END))
                file.close()
            key = sandy.load_key()
            sandy.encrypt_file(filename, key)

    def generate_passwords(self):
        upper = self.upper_var.get()
        lower = self.lower_var.get()
        num = self.num_var.get()
        sym = self.symbols_var.get()
        ext = self.extra_var.get()

        try:
            length = int(self.length_entry.get())
            amount = int(self.amount_entry.get())
        except ValueError:
            messagebox.showerror("Error", "Invalid input for length or amount")
            return

        uppercase = "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        lowercase = uppercase.lower()
        numbers = "0123456789"
        symbols = "!@#£$%&/{}()[]=?+\\^'*-_.:,;<> "
        extra = '"´¤`¨~|½§öäåàáâãéêõóôúíçÖÄÅÀÁÂÃÉÊÕÓÔÚÍÇ'
        choosen_characters = ""
        if upper:
            choosen_characters += uppercase
        if lower:
            choosen_characters += lowercase
        if num:
            choosen_characters += numbers
        if sym:
            choosen_characters += symbols
        if ext:
            choosen_characters += extra

        passwords = []
        for i in range(amount):
            password = "".join(random.choice(choosen_characters) for i in range(length))
            passwords.append(password)

        possibilities = "{:.2e}".format(len(choosen_characters) ** length)
        print("\n"f"You have {possibilities} different password combinations")
        print(f"({len(choosen_characters) ** length})")
        print("\n""chararacters in use", len(choosen_characters), "\n")

        result_text = "\n".join(f"{i + 1}: {password}" for i, password in enumerate(passwords))
        self.password_display.delete(1.0, tk.END)
        self.password_display.insert(tk.END, result_text)

        self.password_display.tag_configure("highlight", background="yellow")
        self.password_display.tag_bind("highlight", "<Button-1>", self.show_save_button)